@@ -24,12 +24,15 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
+#include "about.h"
 #include "formatter.h"
 #include "kweathersettings.h"
 #include "locationquerymodel.h"
 #include "temperaturechartdata.h"
-#include "about.h"
 #include "version.h"
+#ifndef Q_OS_ANDROID
+#include "weatherbackground.h"
+#endif
 #include "weatherlocation.h"
 #include "weatherlocationmodel.h"
 
@@ -65,7 +68,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                          i18n("A convergent weather application for Plasma"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2022 Plasma Development Team"));
-    aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/kweather/-/issues?sort=created_date&state=opened");
+    aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=kweather");
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("espidev@gmail.com"), QStringLiteral("https://espi.dev"));
     KAboutData::setApplicationData(aboutData);
@@ -82,13 +85,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     WeatherLocation *emptyWeatherLocation = new WeatherLocation();
     engine.rootContext()->setContextProperty(QStringLiteral("emptyWeatherLocation"), emptyWeatherLocation);
-
+#ifdef Q_OS_ANDROID
+    engine.rootContext()->setContextProperty(QStringLiteral("KWEATHER_IS_ANDROID"), true);
+#else
+    engine.rootContext()->setContextProperty(QStringLiteral("KWEATHER_IS_ANDROID"), false);
+#endif
     Formatter formatter;
     qmlRegisterSingletonInstance<Formatter>("kweather", 1, 0, "Formatter", &formatter);
 
     qmlRegisterType<TemperatureChartData>("kweather", 1, 0, "TemperatureChartData");
     qmlRegisterType<LocationQueryModel>("kweather", 1, 0, "LocationQueryModel");
     qmlRegisterType<WeatherLocation>("kweather", 1, 0, "WeatherLocation");
+#ifndef Q_OS_ANDROID
+    qmlRegisterType<WeatherBackgroundRenderer>("kweather", 1, 0, "WeatherBackground");
+#endif
 
     qRegisterMetaType<KWeatherCore::HourlyWeatherForecast>();
     qRegisterMetaType<KWeatherCore::DailyWeatherForecast>();
